@@ -65,3 +65,10 @@
 #define run_only_once \
 	static int _once_per_##__func__ = 0; \
 	for (; _once_per_##__func__ == 0; _once_per_##__func__ = 1)
+
+#define trace(...) \
+	do { \
+		char buf_[1024]; \
+		snprintf(buf_, sizeof(buf_), __VA_ARGS__); \
+		printf("\x1B[0;34m" "%s():%d - " "\x1B[0;31m" "%s" "\x1B[0m" "\n", __func__, __LINE__, buf_); \
+	} while (0)
